@@ -1,24 +1,22 @@
 /* algol.h */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
+-- This file is part of GNU MARST, an Algol-to-C translator.
 --
--- This file is part of GNU MARST.
+-- Copyright (C) 2000, 2001, 2002, 2007 Free Software Foundation, Inc.
 --
--- GNU MARST is free software; you can redistribute it and/or modify
+-- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
+-- the Free Software Foundation, either version 3 of the License, or
+-- (at your option) any later version.
 --
--- GNU MARST is distributed in the hope that it will be useful, but
--- WITHOUT ANY WARRANTY; without even the implied warranty of
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
 -- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 -- General Public License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with GNU MARST; see the file COPYING. If not, write to the
--- Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
--- MA 02111-1307, USA.
+-- along with this program. If not, see <http://www.gnu.org/licenses/>.
 ----------------------------------------------------------------------*/
 
 #ifndef _ALGOL_H
