@@ -3,7 +3,8 @@
 /*----------------------------------------------------------------------
 -- This file is part of GNU MARST, an Algol-to-C translator.
 --
--- Copyright (C) 2000, 2001, 2002, 2007 Free Software Foundation, Inc.
+-- Copyright (C) 2000, 2001, 2002, 2007, 2013 Free Software Foundation,
+-- Inc.
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -28,7 +29,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.6";
+static char *version = "MACVT -- Algol 60 Converter, Version 2.7";
 /* Version information. */
 
 static char *infilename = "";
@@ -957,8 +958,8 @@ static void display_help(char *my_name)
 
 static void display_version(void)
 {     printf("%s\n", version);
-      printf("Copyright (C) 2000, 2001, 2002, 2007 Free Software Founda"
-         "tion, Inc.\n");
+      printf("Copyright (C) 2000, 2001, 2002, 2007, 2013 Free Software "
+         "Foundation, Inc.\n");
       printf("This program is free software; you may redistribute it un"
          "der the terms of\n");
       printf("the GNU General Public License. This program has absolute"
